Respite
=======

About
-----

Respite conforms Django to Representational State Transfer (and, incidentally, HTTP).

Documentation
-------------

Respite's documentation is available on `Read the Docs <http://readthedocs.org/docs/django-respite>`_.
